@@ -4,6 +4,8 @@ from modeller.error import ModellerError
 class Logger(object):
     """Allow messages to be printed to the Modeller logfile"""
 
+    _header = _modeller.mod_header_get()
+
     def __init__(self):
         self.header_written = False
         # Use our own write function for all log output
@@ -50,7 +52,8 @@ class Logger(object):
         """Write the Modeller header to the log, but only once"""
         if not self.header_written:
             if self.output:
-                self.write(_modeller.mod_header_get())
+                self.write(self._header)
+            _modeller.mod_header_written_set(True)
             self.header_written = True
         # Use standard method for further logging
         _modeller.mod_log_function_set(self.write)
